@@ -108,11 +108,6 @@ split_line_lha (char *line)
 		fields[i++] = g_strdup ("");
 		fields[i++] = g_strdup ("");
 		line += strlen ("[MS-DOS]");
-
-	} else if (strncmp (line, "[generic]", 9) == 0) {
-		fields[i++] = g_strdup ("");
-		fields[i++] = g_strdup ("");
-		line += strlen ("[generic]");
 	}
 
 	scan = eat_spaces (line);
@@ -138,9 +133,6 @@ get_last_field_lha (char *line)
 	if (strncmp (line, "[MS-DOS]", 8) == 0) 
 		n--;
 
-	if (strncmp (line, "[generic]", 9) == 0) 
-		n--;
-
 	field = eat_spaces (line);
 	for (i = 0; i < n; i++) {
 		field = strchr (field, ' ');
@@ -203,7 +195,6 @@ fr_command_lha_list (FRCommand *comm)
 				      process_line,
 				      comm);
 
-	fr_process_clear (comm->process);
 	fr_process_begin_command (comm->process, "lha");
 	fr_process_add_arg (comm->process, "lq");
 	fr_process_add_arg (comm->process, comm->e_filename);
