@@ -221,7 +221,6 @@ fr_command_zip_list (FRCommand *comm)
 				      list__process_line,
 				      comm);
 
-	fr_process_clear (comm->process);
 	fr_process_begin_command (comm->process, "unzip");
 	fr_process_add_arg (comm->process, "-qq");
 	fr_process_add_arg (comm->process, "-v");
@@ -390,8 +389,12 @@ static void
 fr_command_zip_handle_error (FRCommand   *comm, 
 			     FRProcError *error)
 {
-	if ((error->type == FR_PROC_ERROR_GENERIC) && (error->status <= 1))
-		error->type = FR_PROC_ERROR_NONE;
+	if (error->type == FR_PROC_ERROR_GENERIC) {
+		if (error->status <= 1)
+			error->type = FR_PROC_ERROR_NONE;
+		else if (error->status == 82)
+			error->type = FR_PROC_ERROR_ASK_PASSWORD;
+	}
 }
 
 
