@@ -59,6 +59,7 @@ fr_command_info_new ()
 	c_info->args = NULL;
 	c_info->dir = NULL;
 	c_info->sticky = FALSE;
+	c_info->ignore_error = FALSE;
 
 	return c_info;
 }
@@ -282,6 +283,19 @@ fr_process_set_sticky (FRProcess *fr_proc,
 }
 
 
+void
+fr_process_set_ignore_error (FRProcess *fr_proc, 
+			     gboolean   ignore_error)
+{
+	FRCommandInfo *c_info;
+
+	g_return_if_fail (fr_proc != NULL);
+
+	c_info = g_ptr_array_index (fr_proc->comm, fr_proc->n_comm);
+	c_info->ignore_error = ignore_error;
+}
+
+
 void
 fr_process_add_arg (FRProcess  *fr_proc, 
 		    const char *arg)
@@ -610,6 +624,8 @@ check_child (gpointer data)
 	pid_t           pid;
 	int             status;
 
+	c_info = g_ptr_array_index (fr_proc->comm, fr_proc->current_command);
+
 	/* Remove check. */
 
 	g_source_remove (fr_proc->log_timeout);	
@@ -627,6 +643,11 @@ check_child (gpointer data)
 		return FALSE;
 	}
 
+	if (c_info->ignore_error) {
+		fr_proc->error.type = FR_PROC_ERROR_NONE;
+		g_print ("[ignore error]\n");
+	}
+
 	if (fr_proc->error.type != FR_PROC_ERROR_STOPPED) {
 		if (WIFEXITED (status)) {
 			if (WEXITSTATUS (status) == 0)
@@ -658,7 +679,6 @@ check_child (gpointer data)
 
 	/**/
 
-	c_info = g_ptr_array_index (fr_proc->comm, fr_proc->current_command);
 	if (c_info->end_func != NULL)
 		(*c_info->end_func) (c_info->end_data);
 
@@ -749,19 +769,10 @@ fr_process_start (FRProcess *fr_proc)
 	fr_proc->current_command = 0;
 	fr_proc->error.type = FR_PROC_ERROR_NONE;
 
+	fr_proc->running = TRUE;
 	fr_proc->stopping = FALSE;
 
-	if (fr_proc->n_comm == -1) {
-		fr_proc->running = FALSE;
-		g_signal_emit (G_OBJECT (fr_proc),
-                               fr_process_signals[DONE],
-                               0,
-                               &fr_proc->error);
-		
-        } else {
-                fr_proc->running = TRUE;
-                start_current_command (fr_proc);
-        }
+	start_current_command (fr_proc);
 }
 
 
