@@ -64,6 +64,11 @@ typedef struct {
 	FRArchive *new_archive;
 } FRConvertData;
 
+typedef enum {
+	FR_CLIPBOARD_OP_CUT,
+	FR_CLIPBOARD_OP_COPY
+} FRClipboardOp;
+
 typedef struct {
         GtkWidget *      app;
 	GtkWidget *      list_view;
@@ -75,6 +80,11 @@ typedef struct {
 	GtkWidget *      location_entry;
 	GtkWidget *      location_label;
 	GtkWidget *      up_button;
+	GtkWidget *      home_button;
+	GtkWidget *      back_button;
+	GtkWidget *      fwd_button;
+
+	GtkTooltips     *tooltips;
 
 	GtkWidget *      up_arrows[5];
 	GtkWidget *      down_arrows[5];
@@ -105,7 +115,8 @@ typedef struct {
 	GtkSortType      sort_type;
 
 	WindowListMode   list_mode;
-	char *           current_dir;
+	GList *          history;
+	GList *          history_current;
 	char *           password;
 	FRCompression    compression;
 
@@ -120,6 +131,10 @@ typedef struct {
 
 	gboolean         stoppable;
 
+	GList           *clipboard;
+	guint            clipboard_op : 1;
+	char            *clipboard_current_dir;
+
 	/* Menu items. */
 
 	GtkWidget *      mitem_new_archive;
@@ -134,8 +149,12 @@ typedef struct {
 	GtkWidget *      mitem_rename_archive;
 	GtkWidget *      mitem_delete_archive;
 
+	GtkWidget *      mitem_cut;
+	GtkWidget *      mitem_copy;
+	GtkWidget *      mitem_paste;
 	GtkWidget *      mitem_select_all;
 	GtkWidget *      mitem_unselect_all;
+	GtkWidget *      mitem_rename;
 
 	GtkWidget *      mitem_view_toolbar;
 	GtkWidget *      mitem_view_statusbar;
@@ -164,7 +183,7 @@ typedef struct {
 	GtkWidget *      toolbar_stop;
 
 	GtkWidget *      file_popup_menu;
-	GtkWidget *      popupmenu_file[8];
+	GtkWidget *      popupmenu_file[14];
 
 	EggRecentViewGtk *recent_view;
 	EggRecentModel   *recent_model;
@@ -247,9 +266,13 @@ void       window_archive_reload            (FRWindow      *window);
 void       window_archive_rename            (FRWindow      *window, 
 					     const char    *filename);
 
-void       window_archive_add_files         (FRWindow      *window,
+void       window_archive_add               (FRWindow      *window,
 					     GList         *file_list,
-					     gboolean       update);
+					     const char    *base_dir,
+					     const char    *dest_dir,
+					     gboolean       update,
+					     const char    *password,
+					     FRCompression  compression);
 
 void       window_archive_add_with_wildcard (FRWindow      *window,
 					     const char    *include_files,
@@ -272,6 +295,10 @@ void       window_archive_add_directory     (FRWindow      *window,
 					     const char    *password,
 					     FRCompression  compression);
 
+void       window_archive_remove            (FRWindow      *window,
+					     GList         *file_list,
+					     FRCompression  compression);
+
 void       window_archive_extract           (FRWindow      *window,
 					     GList         *file_list,
 					     const char    *extract_to_dir,
@@ -290,8 +317,14 @@ void       window_set_password              (FRWindow      *window,
 void       window_go_to_location            (FRWindow       *window, 
 					     const char     *path);
 
+const char*window_get_current_location      (FRWindow       *window);
+
 void       window_go_up_one_level           (FRWindow       *window);
 
+void       window_go_back                   (FRWindow       *window);
+
+void       window_go_forward                (FRWindow       *window);
+
 void       window_set_list_mode             (FRWindow       *window, 
 					     WindowListMode  list_mode);
 
@@ -308,6 +341,14 @@ GList *    window_get_file_list_selection   (FRWindow    *window,
 GList *    window_get_file_list_pattern     (FRWindow    *window,
 					     const char  *pattern);
 
+void       window_rename_selection          (FRWindow    *window);
+
+void       window_cut_selection             (FRWindow    *window);
+
+void       window_copy_selection            (FRWindow    *window);
+
+void       window_paste_selection           (FRWindow    *window);
+
 /**/
 
 void       window_stop                      (FRWindow    *window);
